from django.contrib.admin.templatetags.admin_list import paginator_number,pagination,result_list, date_hierarchy, search_form, admin_list_filter, admin_actions
from djinja import template
import jinja2 

register = template.Library()
register.tag(paginator_number)

register.inclusion_tag('admin/pagination.html', pagination)
register.inclusion_tag('admin/change_list_results.html', result_list)
register.inclusion_tag('admin/date_hierarchy.html', date_hierarchy)
register.inclusion_tag('admin/search_form.html', search_form)
register.inclusion_tag('admin/filter.html', admin_list_filter)
register.inclusion_tag('admin/actions.html', admin_actions, True)


"""
Djinja
~~~~~~

`Djinja <http://github.com/syrusakbary/djinja>` tries to integrate `Jinja2
<http://jinja.pocoo.org/2/>` in `Django <http://www.djangoproject.com/>`. The aim is to replace
completely the Django's template system, including administration.

:copyright: 2011 by Syrus Akbary Nieto
:license: BSD, see LICENSE for more details.
"""

#Taked majoritarily from Coffin's <http://www.github.com/dcramer/coffin> __init__.py

__all__ = ('__version__', '__build__', '__docformat__', 'get_revision')
__version__ = (0, 5, 0)
__docformat__ = 'restructuredtext en'

import os

def _get_git_revision(path):
    revision_file = os.path.join(path, 'refs', 'heads', 'master')
    if not os.path.exists(revision_file):
        return None
    fh = open(revision_file, 'r')
    try:
        return fh.read()
    finally:
        fh.close()

def get_revision():
    """
    :returns: Revision number of this branch/checkout, if available. None if
        no revision number can be determined.
    """
    package_dir = os.path.dirname(__file__)
    checkout_dir = os.path.normpath(os.path.join(package_dir, '..'))
    path = os.path.join(checkout_dir, '.git')
    if os.path.exists(path):
        return _get_git_revision(path)
    return None

__build__ = get_revision()


from djinja import template
from django.contrib.admin.models import LogEntry
import jinja2 


register = template.Library()

@jinja2.contextfunction
def get_admin_log(context,limit,user=None):
    if user is None:
        return LogEntry.objects.all().select_related('content_type', 'user')[:limit]
    else:
        #user_id = user
        user_id = user.id
        #raise Exception(context['user'])
        return LogEntry.objects.filter(user__id__exact=user_id).select_related('content_type', 'user')[:limit]

register.tag(get_admin_log)


from djinja.template.base import Library
from django.utils.importlib import import_module
import jinja2

register = Library()

# def execute (lib,function,*args,**kwargs):
#     l = import_module(lib)
#     #raise Exception(args)
#     f = getattr(l,function)
#     return f(*args,**kwargs)
# register.tag(execute)
# 
# @jinja2.contextfunction
# def execute_context (context,lib,function,*args,**kwargs):
#     l = import_module(lib)
#     #raise Exception(args)
#     context_dict = {}
#     for d in context.keys():
#         context_dict[d] = context.get(d)
#     f = getattr(l,function)
#     return f(context_dict,*args,**kwargs)
# 
# register.tag(execute_context)

from django.core import urlresolvers

def url(viewname,*args,**kwargs):
    try:
        return urlresolvers.reverse(viewname,args=args,kwargs=kwargs)
    except:
        return False
register.tag(url)

class Load(object):
    def __init__(self,module):
        from django.template import get_library
        self._module = get_library(module)
        #raise Exception(self._module.globals)

    @property
    def globals(self):
        return self._module.globals

    def __getitem__ (self,key):
        return self.globals[key]
register.tag(Load,name='load')



from djinja import template
from django.core.urlresolvers import reverse

import jinja2
register = template.Library()
@jinja2.contextfunction
def active (context,*args):
    if context['request_path'] in ( reverse(url) for url in args ):
        return True
    return False
    
register.tag(active)
